summaryrefslogtreecommitdiff
path: root/source3/include
diff options
context:
space:
mode:
authorJeremy Allison <jra@samba.org>2003-01-28 21:09:56 +0000
committerJeremy Allison <jra@samba.org>2003-01-28 21:09:56 +0000
commit734c6d8a513272c6e65ba60c62e21080c4339b8d (patch)
treeeb4008ba0d684b2bf8aaf8b2f01106dbd7878737 /source3/include
parent3a9dfe6384329d2039a32be44127ac121e75533f (diff)
downloadsamba-734c6d8a513272c6e65ba60c62e21080c4339b8d.tar.gz
samba-734c6d8a513272c6e65ba60c62e21080c4339b8d.tar.bz2
samba-734c6d8a513272c6e65ba60c62e21080c4339b8d.zip
Merging tridge's privillage client changes from HEAD.
Jeremy. (This used to be commit 30a33920b4d834edc877cc0080291fbda983083a)
Diffstat (limited to 'source3/include')
-rw-r--r--source3/include/rpc_lsa.h25
-rw-r--r--source3/include/rpc_misc.h6
2 files changed, 23 insertions, 8 deletions
diff --git a/source3/include/rpc_misc.h b/source3/include/rpc_misc.h
index 1b956826eb..7710489435 100644
--- a/source3/include/rpc_misc.h
+++ b/source3/include/rpc_misc.h
@@ -217,15 +217,15 @@ typedef struct
uint16 size;
uint32 ref_id;
UNISTR2 string;
-} UNISTR_ARRAY_EL;
+} UNISTR2_ARRAY_EL;
/* an array of unicode strings */
typedef struct
{
uint32 ref_id;
uint32 count;
- UNISTR_ARRAY_EL *strings;
-} UNISTR_ARRAY;
+ UNISTR2_ARRAY_EL *strings;
+} UNISTR2_ARRAY;
/* DOM_RID2 - domain RID structure for ntlsa pipe */
typedef struct domrid2_info
diff --git a/source3/include/rpc_lsa.h b/source3/include/rpc_lsa.h
index a220b3f70d..78dbae4cdf 100644
--- a/source3/include/rpc_lsa.h
+++ b/source3/include/rpc_lsa.h
@@ -515,23 +515,38 @@ typedef struct lsa_r_enum_privs
NTSTATUS status;
} LSA_R_ENUM_PRIVS;
/* LSA_Q_ENUM_ACCOUNTS - LSA enum account rights */
typedef struct lsa_q_enum_acct_rights
{
POLICY_HND pol; /* policy handle */
- uint32 count; /* what is this for in the query? */
- DOM_SID sid;
+ DOM_SID2 sid;
} LSA_Q_ENUM_ACCT_RIGHTS;
/* LSA_R_ENUM_ACCOUNTS - LSA enum account rights */
typedef struct lsa_r_enum_acct_rights
{
uint32 count;
- UNISTR_ARRAY rights;
+ UNISTR2_ARRAY rights;
NTSTATUS status;
} LSA_R_ENUM_ACCT_RIGHTS;
+/* LSA_Q_ADD_ACCT_RIGHTS - LSA add account rights */
+typedef struct
+{
+ POLICY_HND pol; /* policy handle */
+ DOM_SID2 sid;
+ UNISTR2_ARRAY rights;
+ uint32 count;
+} LSA_Q_ADD_ACCT_RIGHTS;
+
+/* LSA_R_ADD_ACCT_RIGHTS - LSA add account rights */
+typedef struct lsa_r_add_acct_rights
+{
+ NTSTATUS status;
+} LSA_R_ADD_ACCT_RIGHTS;
+
+
/* LSA_Q_PRIV_GET_DISPNAME - LSA get privilege display name */
typedef struct lsa_q_priv_get_dispname
{
@@ -515,23 +515,38 @@ typedef struct lsa_r_enum_privs
NTSTATUS status;
} LSA_R_ENUM_PRIVS;
-/* LSA_Q_ENUM_ACCOUNTS - LSA enum account rights */
+/* LSA_Q_ENUM_ACCT_RIGHTS - LSA enum account rights */
typedef struct lsa_q_enum_acct_rights
{
@@ -515,23 +515,38 @@ typedef struct lsa_r_enum_privs
} LSA_Q_ENUM_ACCT_RIGHTS;
-/* LSA_R_ENUM_ACCOUNTS - LSA enum account rights */
+/* LSA_R_ENUM_ACCT_RIGHTS - LSA enum account rights */
typedef struct lsa_r_enum_acct_rights
{